@@ -1,9 +1,9 @@
 import requests
 
-from myfeeds_ai.data_feeds.models.Model__Data_Feeds__Raw_Data import Model__Data_Feeds__Raw_Data
-from osbot_utils.type_safe.Type_Safe                                      import Type_Safe
-from osbot_utils.context_managers.capture_duration                       import capture_duration
-from osbot_utils.utils.Http                                              import url_join_safe
+from myfeeds_ai.data_feeds.models.Model__Data_Feeds__Raw_Data       import Model__Data_Feeds__Raw_Data
+from osbot_utils.type_safe.Type_Safe                                import Type_Safe
+from osbot_utils.helpers.duration.decorators.capture_duration       import capture_duration
+from osbot_utils.utils.Http                                         import url_join_safe
 
 class Data_Feeds__Http_Content(Type_Safe):
     server : str
