@@ -4,4 +4,7 @@ from enum import Enum
 class Model__Data_Feeds__Providers(Enum):
     HACKER_NEWS         : str = 'hacker-news'
     OPEN_SECURITY_SUMMIT: str = 'open-security-summit'
+    OWASP               : str = 'owasp'
+    PERSONAS            : str = 'personas'
+
 
